Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(894)

Unified Diff: content/browser/service_worker/embedded_worker_instance.cc

Issue 2096643002: Eliminate MojoApplicationHost (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mah3
Patch Set: . Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/embedded_worker_instance.cc
diff --git a/content/browser/service_worker/embedded_worker_instance.cc b/content/browser/service_worker/embedded_worker_instance.cc
index 0dba1ed32d97a13e44ab4d2ed25aa8cb61db3e1c..433481d35b47caf1684d3ed3bcaffeef1a596019 100644
--- a/content/browser/service_worker/embedded_worker_instance.cc
+++ b/content/browser/service_worker/embedded_worker_instance.cc
@@ -27,6 +27,7 @@
#include "content/public/browser/render_process_host.h"
#include "content/public/common/child_process_host.h"
#include "ipc/ipc_message.h"
+#include "services/shell/public/cpp/interface_provider.h"
#include "url/gurl.h"
namespace content {
@@ -106,11 +107,11 @@ void SetupMojoOnUIThread(
shell::mojom::InterfaceProviderRequest services,
shell::mojom::InterfaceProviderPtrInfo exposed_services) {
RenderProcessHost* rph = RenderProcessHost::FromID(process_id);
- // |rph| or its ServiceRegistry may be NULL in unit tests.
- if (!rph || !rph->GetServiceRegistry())
+ // |rph| or its InterfaceRegistry may be NULL in unit tests.
+ if (!rph || !rph->GetInterfaceRegistry())
return;
mojom::EmbeddedWorkerSetupPtr setup;
- rph->GetServiceRegistry()->ConnectToRemoteService(mojo::GetProxy(&setup));
+ rph->GetRemoteInterfaces()->GetInterface(&setup);
setup->ExchangeInterfaceProviders(
thread_id, std::move(services),
mojo::MakeProxy(std::move(exposed_services)));

Powered by Google App Engine
This is Rietveld 408576698